<template>
  <div class="page">
    <div class="content">
      <div v-if="pageShow">
        <van-pull-refresh v-model="refreshing" @refresh="onRefresh(1)">
          <van-list
            v-model="loading"
            :finished="finished"
            finished-text="没有更多了"
          >
            <div class="list" v-for="(item, index) in list" :key="index">
              <div class="list_box" @click="openDetail(item.id)">
                <div class="item_1_box">
                  <div class="item_1_box_f">
                    <div class="item_1">
                      申请时间：<span>{{ item.paymentTime }}</span>
                    </div>
                  </div>
                </div>
                <div class="item_2_box">
                  <div class="item_2">
                    申请人：<span>{{ item.paymentMemberName }}</span>
                  </div>
                  <div class="item_2">
                    出生日期：<span>{{ item.birthdate }}</span>
                  </div>
                  <div class="item_2">
                    新生犬登记卡编号：<span>{{ item.birthCode }}</span>
                  </div>
                  <div class="item_2">
                    血统证书号：<span>{{ item.pedigreeCertifiedCode }}</span>
                  </div>
                  <div class="item_2">
                    父犬主：<span>{{ item.fdogMemberName }}</span>
                  </div>
                  <div class="item_2">
                    父犬证书号：<span>{{ item.fdogPedigreeCertified }}</span>
                  </div>
                  <div class="item_2">
                    父犬主审核状态：
                    <span v-if="item.fdogReviewState == '0' || item.fdogReviewState == ''">
                      <span>待审核</span>
                      <span class="btn" v-if="item.isFdogReview" @click.stop="agreeOpen(item, '父')">同意</span>
                      <span class="btn" v-if="item.isFdogReview" @click.stop="disagreeOpen(item, '父')">不同意</span>
                    </span>
                    <span v-if="item.fdogReviewState == '1'">同意</span>
                    <span v-if="item.fdogReviewState == '2'">
                      <span class="btn" v-if="item.isFdogReview" @click.stop="agreeOpen(item, '父')">同意</span>
                      <span>不同意</span>
                    </span> 
                  </div>
                  <div class="item_2" v-if="item.fdogReviewState == '2'">
                    父犬主不通过原因：<span>{{ item.fdogReviewRemarks }}</span>
                  </div>
                  <div class="item_2">
                    母犬主：<span>{{ item.mdogMemberName }}</span>
                  </div>
                  <div class="item_2">
                    母犬证书号：<span>{{ item.mdogPedigreeCertified }}</span>
                  </div>
                  <div class="item_2">
                    母犬主审核状态：
                    <span v-if="item.mdogReviewState == '0' || item.mdogReviewState  == ''">
                      <span>待审核</span>
                      <span class="btn" v-if="item.isMdogReview" @click.stop="agreeOpen(item, '母')">同意</span>
                      <span class="btn" v-if="item.isMdogReview" @click.stop="disagreeOpen(item, '母')">不同意</span>
                    </span>
                    <span v-if="item.mdogReviewState == '1'">同意</span>
                    <span v-if="item.mdogReviewState == '2'">
                      <span class="btn" v-if="item.isMdogReview" @click.stop="agreeOpen(item, '母')">同意</span>
                      <span>不同意</span>
                    </span> 
                  </div>
                  <div class="item_2" v-if="item.mdogReviewState == '2'">
                    母犬主不通过原因：<span>{{ item.mdogReviewRemarks }}</span>
                  </div>
                </div>
              </div>
            </div>
          </van-list>
        </van-pull-refresh>
      </div>
      <div class="normal" v-else>
        <div class="icon"></div>
        <p>暂无更多数据</p>
      </div>
    </div>
    <van-popup v-model="agreeShow" :close-on-click-overlay="false">
      <div class="popup_box">
        <div class="popup_top_box">
          <div class="popup_top">同意双亲比对</div>
        </div>

        <div class="popup_center">
          <div class="popup_content_1">
            您名下犬只{{ pedigreeCertifiedCode }}所繁殖的后代犬{{newpedigreeCertifiedCode == '' ? birthCode : newpedigreeCertifiedCode }}，于{{paymentTime}}日申请了金质证书业务，是否同意协助办理采集种母（种公）的DNA位点
          </div>
        </div>
        <div class="popup_center">
          <div class="popup_content_2">验证码将发送至您的手机</div>
        </div>
        <div class="popup_center">
          <div class="popup_content_2">
            <span>{{  transferorMemberMobile }}</span>
          </div>
        </div>
        <div class="popup_center">
          <input
            class="inputBox"
            type="text"
            placeholder="请输入验证码"
            maxlength="6"
            :value="smsCode"
            @input="getVal($event, 'smsCode')" oninput="value=value.replace(/[^\d]/g,'')"
          />
          <div class="code" v-if="!disabled">
            <span @click="getTransferSms">获取验证码</span>
          </div>
          <div class="code" v-else>
            <span class="timeout" v-if="isNum">{{ count }}S</span>
            <span v-else @click="getTransferSms">重新获取</span>
          </div>
        </div>

        <div class="popup_field_pading">
          <div class="popup_content_2">备注</div>
          <div class="popup_content_bg">
            <van-field
              v-model="reviewRemarks"
              rows="2"
              autosize
              maxlength="50"
              type="textarea"
              placeholder="请输入留言"
              show-word-limit
            />
          </div>
        </div>
        <div class="btn_box">
          <div class="btn" @click="closeDialogReset()">取消</div>
          <div class="btn" @click="audit(1)">确认</div>
        </div>
      </div>
    </van-popup>

    <van-popup v-model="disagreeShow" :close-on-click-overlay="false">
      <div class="popup_box">
        <div class="popup_top_box">
          <div class="popup_top">不同意双亲比对</div>
        </div>
        <div class="popup_field_pading">
          <div class="popup_content_2">未通过原因</div>
          <div class="popup_content_bg">
            <van-field
              v-model="reviewRemarks"
              rows="2"
              autosize
              maxlength="50"
              type="textarea"
              placeholder="请输入未通过原因"
              show-word-limit
            />
          </div>
        </div>
        <div class="btn_box">
          <div class="btn" @click="closeDialogReset()">取消</div>
          <div class="btn" @click="audit(2)">确认</div>
        </div>
      </div>
    </van-popup>
  </div>
</template>

<script>
import { goldCertifiedAuditList, getPhone, sendVerifyCode, audit } from "@/request/api";
import { Toast } from "vant";
export default {
  data() {
    return {
      active: 0,
      type: 0,
      pageNo: 0, //页码
      list: [],
      loading: false,
      finished: false,
      refreshing: false,
      pageShow: true,

      agreeShow: false,
      disagreeShow: false,

      count: 60,
      isNum: true,
      disabled: false,
      transferorMemberMobile: "",

      id: "",
      reviewRemarks: "",
      smsCode: "",
      pedigreeCertifiedCode: '',
      newpedigreeCertifiedCode: '',
      birthCode: '',
      paymentTime: '',
    };
  },
  created() {
    let token = this.$route.query.token || "";
    sessionStorage.setItem("token", token);
    let club = this.$route.query.club || "";
    sessionStorage.setItem("club", club);
  },
  mounted() {
    this.getList();
    this.getPhone()
  },
  methods: {
    // 获取输入
    getVal(e, type) {
      this[type] = e.target.value.replace(/ /g, "");
    },
    // menu点击事件
    //刷新
    onRefresh() {
      // 清空列表数据
      this.pageNo = 0;
      this.finished = false;
      this.list = [];
      // 重新加载数据
      // 将 loading 设置为 true，表示处于加载状态
      this.loading = true;
      this.getList();
    },
    //登记卡转让-列表 参数：type 1:我的申请 2:等我审核
    getList() {
      Toast.loading({
        message: "加载中...",
        forbidClick: true,
        duration: 0,
      });
      this.pageNo += 1;
      goldCertifiedAuditList({
        pageSize: 10,
        pageNo: this.pageNo,
      }).then((res) => {
        if (res.rc == "0") {
          if (res.list.length > 0) {
            this.pageShow = true;
          } else {
            this.pageShow = false;
          }
          let list = this.list.concat(res.list);
          this.list = list;
          if (res.list.length <= 10) {
            this.finished = true;
          }
        } else {
          Toast(res.msg);
        }
        if (this.refreshing) {
          this.refreshing = false;
        }
        this.loading = false;
      });
    },

    // 获取手机号码
    getPhone(){
      getPhone().then((res) => {
        if (res.rc == "0") {
          let safeMobile = res.data.safeMobile
          this.transferorMemberMobile = safeMobile == '' ?  '' : safeMobile.replace(safeMobile.substring(3, 7),"****")
        } else {
          Toast(res.msg);
        }
      }); 
    },
    // 获取验证码
    getTransferSms() {
      sendVerifyCode().then((res) => {
        let This = this;
        if (res.rc == "0") {
          this.disabled = true;
          let timer = setInterval(() => {
            This.count = This.count - 1;
            This.isNum = true;
            if (This.count == 0) {
              clearInterval(timer);
              This.count = 61;
              This.isNum = false;
            }
          }, 1000);
        } else {
          Toast(res.msg);
        }
      });
    },
    // 验证码格式校验
    checkCode() {
      if (this.smsCode.length == 0) {
        Toast("请输入验证码");
        return false;
      }
      return true;
    },

    //审批
    audit(reviewState) {
      if (reviewState == 1 && !this.checkCode()) return;
      Toast.loading({
        message: "加载中",
        forbidClick: true,
        duration: 0,
      });
      let data = {
        reviewState: reviewState,
        id: this.id,
        pedigreeCertifiedCode: this.pedigreeCertifiedCode,
        reviewRemarks: this.reviewRemarks,
        smsCode: this.smsCode,
      };
      audit(data).then((res) => {
        if (res.rc == "0") {
          //审核成功后将数据置空并刷新页面数据
          this.closeDialogReset();
          this.onRefresh();
        } else {
          Toast(res.msg);
        }
      });
    },
    //关闭弹框重置数据
    closeDialogReset() {
      this.agreeShow = false;
      this.disagreeShow = false;
      this.reviewRemarks = "";
      this.smsCode = "";
      this.newpedigreeCertifiedCode = ''
      this.birthCode = ''
      this.paymentTime = ''
      this.id = "";
    },
    // 不同意点击事件
    disagreeOpen(item, type) {
      this.disagreeShow = true;
      this.id = item.id;
      if(type == '父'){
        this.pedigreeCertifiedCode = item.fdogPedigreeCertified
      }else{
        this.pedigreeCertifiedCode = item.mdogPedigreeCertified
      }
    },
    //同意点击事件
    agreeOpen(item, type) {
      this.agreeShow = true;
      this.id = item.id;
      this.newpedigreeCertifiedCode = item.pedigreeCertifiedCode
      this.birthCode = item.birthCode
      this.paymentTime = item.paymentTime
      if(type == '父'){
        this.pedigreeCertifiedCode = item.fdogPedigreeCertified
      }else{
        this.pedigreeCertifiedCode = item.mdogPedigreeCertified
      }
    },
    //跳转详情
    openDetail(id) {
      this.$router.push({ name: "detail", query: {'id': id}});
    },
  },
};
</script>

<style scoped>
.page {
  min-height: 100vh;
  background-color: #f5f5f5;
}
.topBox {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 2;
  width: 100%;
  background: #fff;
}
.top {
  margin: 0.2rem;
  text-align: center;
  line-height: 1.44rem;
  background: #fff;
  font-size: 0.36rem;
  color: #42637f;
  font-weight: 600;
  background: url(../../assets/apply_entry_bg.png) center center no-repeat;
  background-size: 100% 100%;
}
.nav {
  display: flex;
  justify-content: space-between;
  position: relative;
}
.active {
  color: #29adfe;
}
.menu {
  width: 100%;
  padding: 0.2rem 0;
  font-size: 0.34rem;
  text-align: center;
}
.line {
  position: absolute;
  bottom: 0;
  left: 15%;
  width: 1.5rem;
  height: 0.05rem;
  background: #29adfe;
  border-radius: 0.2rem;
  transition: 0.45s;
}
.lineShow {
  left: 65%;
}
.content {
  box-sizing: border-box;
}
.list {
  padding: 0.2rem;
}
.list_box {
  border-radius: 0.1rem;
  background: #fff;
}

.list_box .item_1_box {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: .3rem;
  font-size: .32rem;
  line-height: .45rem;
  font-weight: 500;
  color: #333333;
  background: url(../../assets/golden_title.png) center center no-repeat;
  background-size: 100% 100%;
}
.item_1_box_f {
  display: flex;
  align-items: center;
}
.list_box .item_1_1 {
  font-size: 0.28rem;
  line-height: 0.4rem;
  color: #0a2433;
  margin: 0.1rem;
  text-align: right;
}
.item_2_box{
  padding: .25rem .3rem;
}
.list_box .item_2_box .item_2 {
  font-size: 0.26rem;
  color: #999999;
  line-height: .7rem;
}
.list_box .item_2_box .item_2 span{
  color: #333;
}
.list_box .item_2_box .item_2_2 {
  font-size: 0.26rem;
  color: #ef4d02;
  line-height: 0.3rem;
  margin: 0.2rem 0;
}
.list_box .item_3_box {
  display: flex;
  align-items: center;
  background-color: #29adfe;
  border-bottom-left-radius: 0.1rem;
  border-bottom-right-radius: 0.1rem;
  display: flex;
  justify-content: center;
  padding: 0.12rem 0;
}
.list_box .item_3_box .item_3 {
  font-size: 0.26rem;
  margin: 0.05rem;
  color: #fff;
}
.list_box .item_3_box .item_3_icon {
  height: 0.17rem;
  width: 0.1rem;
  background: url(../../assets/arrow_right_white.png) center center no-repeat;
  background-size: 100% 100%;
  margin: 0.02rem 0 0 0.08rem;
}
.text_color_green {
  color: #7ed321;
}
.text_color_red {
  color: #a20014;
}
.text_color_orange {
  color: #f5a623;
}
.btn_box {
  display: flex;
  justify-content: center;
}
.btn_box .btn {
  line-height: 0.62rem;
  width: 1.58rem;
  text-align: center;
  border-radius: 0.32rem;
  color: #fff;
  background: #29adfe;
  font-size: 0.22rem;
  margin: 0.2rem;
}
.normal {
  padding-top: 2.7rem;
  text-align: center;
  font-size: 0.32rem;
  line-height: 0.45rem;
  color: #333;
}
.normal .icon {
  display: inline-block;
  height: 1.69rem;
  width: 3.19rem;
  background: url(../../assets/normal.png) center center no-repeat;
  background-size: 100% 100%;
  margin-bottom: 0.3rem;
}

.popup_box {
  border-radius: 0.1rem;
  background: #fff;
  border: 0.01rem solid #cccccc;
}
.popup_box .popup_top_box {
  display: flex;
  align-items: center;
  justify-content: center;
  margin: auto 1rem;
  height: 0.77rem;
  width: 3.66rem;
  background: url(../../assets/dialog_top_bg.png) center center no-repeat;
  background-size: 100% 100%;
}
.popup_box .popup_top_box .popup_top {
  font-size: 0.28rem;
  font-weight: 600;
  color: #fff;
}
.popup_box .popup_top_box .popup_top {
  font-size: 0.32rem;
  font-weight: 600;
  color: #fff;
}
.popup_box .popup_content_1 {
  font-size: 0.28rem;
  color: #d0021b;
  padding: 0.2rem 0.4rem;
}
.popup_field_pading {
  padding: 0 0.2rem;
}
.popup_center {
  display: flex;
  align-items: center;
  justify-content: center;
}
.popup_box .popup_content_2 {
  font-size: 0.26rem;
  padding-top: 0.1rem;
  padding-bottom: 0.1rem;
  color: #333333;
}
.popup_box .popup_content_bg {
  border-radius: 0.05rem;
  width: 100%;
  border: 0.01rem solid #cccccc;
}

.inputBox {
  height: 0.88rem;
  width: 3.5rem;
  background: #f3f7fc;
  border-radius: 0.42rem;
  padding: 0.2rem 0 0.2rem 0.6rem;
  line-height: 0.45rem;
  box-sizing: border-box;
  margin-bottom: 0.5rem;
  margin-right: 0.1rem;
  font-size: 0.32rem;
  position: relative;
}
.code {
  height: 0.88rem;
  font-weight: bold;
  color: #2e2e2e;
  font-size: 0.28rem;
}
.code .timeout {
  height: 0.88rem;
  color: #fff;
  padding: 0.1rem 0.3rem;
  background: #cad4e1;
  font-size: 0.28rem;
  border-radius: 0.25rem;
}
.btn{
  height: .5rem;
  width: 1.2rem;
  display: inline-block;
  line-height: .5rem;
  text-align: center;
  margin: 0 .1rem;
  background: #29adfe;
  color: #FFFFFF!important;
  border-radius: 1rem;
}
</style>